@@ -1,6 +1,6 @@
 """
 # -*- coding: utf-8 -*-
-#====================================================================================================================
+#===============================================================================
 #
 # Copyright (C) 2013/2014 Laurent Champagnac
 #
@@ -16,8 +16,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-#====================================================================================================================
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+#===============================================================================
 """
 
 # Logger
@@ -290,7 +290,7 @@ class TcpServer(DisposableObject):
             for idx in range(self._tcpServerConfig.childProcessCount):
                 # Fork gevent hub
                 # GEVENT_RC1 fix : hub.fork => os.fork
-                _forkPid = gevent.os.fork()
+                _forkPid = gevent.fork()
 
                 logger.info("_startServer : Forking gevent hub done, idx=%s, forkPid=%s, %s", idx, _forkPid,
                             SolBase.getCurrentPidsAsString())
@@ -506,7 +506,7 @@ class TcpServer(DisposableObject):
     def _removeClient_stopInternal(self, oldClient, evt):
         """
         Remove internal
-        :param oldClient: olclient
+        :param oldClient: oldclient
         :param evt: gevent.Event
         :type evt: gevent.Event
         :type oldClient: TcpServerClientContext
@@ -527,14 +527,14 @@ class TcpServer(DisposableObject):
     def _removeClient_stopBusiness(self, oldClient, evt):
         """
         Remove internal
-        :param oldClient: olclient
+        :param oldClient: oldclient
         :param evt: gevent.Event
         :type evt: gevent.Event
         :type oldClient: TcpServerClientContext
         """
 
         #-------------------------
-        # Stop the client (biz call here)
+        # Stop the client (Business call here)
         # We do NOT call if :
         # - service is stopping AND onStopCallClientStopSynch==False
         #-------------------------
@@ -544,7 +544,7 @@ class TcpServer(DisposableObject):
 
             logger.debug("_removeClient_stopBusiness call, clientId=%s", clientId)
 
-            if self._isRunning == True:
+            if self._isRunning:
                 #-------------------
                 # Running, call
                 #-------------------
@@ -606,7 +606,7 @@ class TcpServer(DisposableObject):
 
                 localEvt.wait(self._tcpServerConfig.stopClientTimeoutMs / 1000.0)
 
-                if localEvt.isSet() == False:
+                if not localEvt.isSet():
                     # Flush out warning
                     s = "Greenlet dump, g={0}, frame={1}".format(g1, ''.join(traceback.format_stack(g1.gr_frame)))
 
@@ -636,7 +636,7 @@ class TcpServer(DisposableObject):
 
                 localEvt.wait(self._tcpServerConfig.stopClientTimeoutMs / 1000.0)
 
-                if localEvt.isSet() == False:
+                if not localEvt.isSet():
                     # Flush out warning
                     s = "Greenlet dump, g={0}, frame={1}".format(g2, ''.join(traceback.format_stack(g2.gr_frame)))
 
